@@ -28,7 +28,7 @@ pomp(
        beta.sd=0,
        pop=1400,
        rho=0.9,sigma=3.6,
-       S.0=0.999,I.0=0.001,R.0=0
+       S_0=0.999,I_0=0.001,R_0=0
        ),
      rprocess=euler.sim(
        step.fun="_sir_euler_simulator",
@@ -39,22 +39,19 @@ pomp(
      skeleton="_sir_ODE",
      measurement.model=reports~nbinom(mu=rho*cases,size=1/sigma^2),
      PACKAGE="pomp",
-     obsnames = c("reports"),
      statenames=c("S","I","R","cases","W"),
      paramnames=c(
        "gamma","mu","iota",
-       "beta","beta.sd","pop","rho","sigma",
-       "S.0","I.0","R.0"
+       "beta","beta.sd","pop","rho",
+       "S_0","I_0","R_0"
        ),
      zeronames=c("cases"),
-     comp.names=c("S","I","R"),
-     ic.names=c("S.0","I.0","R.0"),
      nbasis=1L,
      degree=0L,
      period=1.0,
      logvar=c(
        "beta","gamma","mu","iota","sigma","beta.sd",
-       "S.0","I.0","R.0"
+       "S_0","I_0","R_0"
        ),
      logitvar="rho",
      toEstimationScale=function (params, logvar, logitvar, ...) {
@@ -67,14 +64,7 @@ pomp(
        params[logitvar] <- plogis(params[logitvar])
        params
      },
-     initializer=function(params, t0, comp.names, ic.names, ...) {
-       snames <- c("S","I","R","cases","W")
-       fracs <- params[ic.names]
-       x0 <- numeric(length(snames))
-       names(x0) <- snames
-       x0[comp.names] <- round(params['pop']*fracs/sum(fracs))
-       x0
-     }
+     initializer="_sir_init"
      ) -> bbs
 
 c("bbs")
